"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const chai = require("chai");
chai.use(require("chai-as-promised"));
const FacebookAuthProvider_1 = require("./FacebookAuthProvider");
const errors = require("../../errors");
const TestServer_1 = require("../../TestServer");
const AuthService_1 = require("../../services/AuthService");
const validAccessToken = 'EAACRlUPa8hQBAPvaEjlfjsW7i8D06Boqfu1faZCCyxVizLsHMgK0qZB7nirZADJCsuJNOja9231C3r4nEiILdmZCgaIwmkfEwTxJ3vLMVehA8TgiZC2H357sZCkzLdqeEionr68LpZAcACjZCWMuV9zYUePWbLH6UGdRho3YiZC8TrjONJgZAd7dJA65oHS8Dj9DIcyOis1wsLO4gb2FV4ZCuHQhtRuywJGZCRE7a9UMZAPYXgAZDZD';
const recordedAt = 1505930192605;
describe("FacebookAuthProvider", () => {
    let provider;
    let server;
    let authService;
    function createServer(params = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            server = new TestServer_1.TestServer();
            authService = new AuthService_1.AuthService();
            provider = new FacebookAuthProvider_1.FacebookAuthProvider();
            authService.addProvider(provider);
            server.addService(authService);
            yield server.start();
        });
    }
    afterEach(() => __awaiter(this, void 0, void 0, function* () {
        if (server) {
            yield server.shutdown();
        }
    }));
    describe("authenticateOrCreateUser", () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () { return createServer(); }));
        describe("without data param", () => {
            it("should return a MissingParamaters exception", () => __awaiter(this, void 0, void 0, function* () {
                yield chai_1.assert.isRejected(provider.authenticateOrCreateUser({}), errors.realm.MissingParameters);
            }));
        });
        describe("with invalid access token", () => {
            it("should return an InvalidCredentials exception", () => __awaiter(this, void 0, void 0, function* () {
                yield chai_1.assert.isRejected(provider.authenticateOrCreateUser({ data: "isInvalid" }), errors.realm.InvalidCredentials);
            }));
        });
        describe("on first request", () => {
            it.skip("should return a user", () => __awaiter(this, void 0, void 0, function* () {
                const user = yield chai_1.assert.isFulfilled(provider.authenticateOrCreateUser({ data: validAccessToken }));
                chai_1.assert.isTrue(user.created);
                chai_1.assert.isDefined(user.userId);
                chai_1.assert.isFalse(user.isAdmin);
                chai_1.assert.equal(user.accounts[0].provider, "facebook");
                chai_1.assert.isDefined(user.accounts[0].providerId);
                chai_1.assert.notEqual(user.accounts[0].providerId, validAccessToken);
            }));
        });
        describe("on subsequent requests", () => {
            it.skip("should return a user", () => __awaiter(this, void 0, void 0, function* () {
                const user = yield chai_1.assert.isFulfilled(provider.authenticateOrCreateUser({ data: validAccessToken }));
                const secondUser = yield chai_1.assert.isFulfilled(provider.authenticateOrCreateUser({ data: validAccessToken }));
                chai_1.assert.equal(user.userId, secondUser.userId);
                chai_1.assert.equal(user.accounts[0].providerId, secondUser.accounts[0].providerId);
            }));
        });
    });
});
//# sourceMappingURL=FacebookAuthProvider.spec.js.map